@@ -32,6 +32,35 @@ typedef enum {
     NETPLAN_OPTIONAL_STATIC  = 1<<4,
 } NetplanOptionalAddressFlag;
 
+typedef enum
+{
+    /**
+     * @brief Tristate enum type
+     *
+     * This type defines a boolean which can be unset, i.e.
+     * this type has three states. The enum is ordered so
+     * that
+     *
+     * UNSET -> -1
+     * FALSE -> 0
+     * TRUE  -> 1
+     *
+     * And the integer values can be used directly when
+     * converting to string.
+     */
+    NETPLAN_TRISTATE_UNSET = -1, /* -1 */
+    NETPLAN_TRISTATE_FALSE,      /*  0 */
+    NETPLAN_TRISTATE_TRUE,       /*  1 */
+} NetplanTristate;
+
+typedef enum
+{
+    NETPLAN_USE_DOMAIN_MODE_UNSET = -1,
+    NETPLAN_USE_DOMAIN_MODE_FALSE,
+    NETPLAN_USE_DOMAIN_MODE_TRUE,
+    NETPLAN_USE_DOMAIN_MODE_ROUTE,
+} NetplanUseDomainMode;
+
 /* Fields below are valid for dhcp4 and dhcp6 unless otherwise noted. */
 typedef struct dhcp_overrides {
     gboolean use_dns;
@@ -45,6 +74,12 @@ typedef struct dhcp_overrides {
     guint metric;
 } NetplanDHCPOverrides;
 
+typedef struct ra_overrides {
+    NetplanTristate use_dns;
+    NetplanUseDomainMode use_domains;
+    guint table;
+} NetplanRAOverrides;
+
 typedef enum {
     NETPLAN_RA_MODE_KERNEL,
     NETPLAN_RA_MODE_ENABLED,
@@ -179,27 +214,6 @@ typedef struct netplan_backend_settings {
     GData* passthrough; /* See g_datalist* functions */
 } NetplanBackendSettings;
 
-typedef enum
-{
-    /**
-     * @brief Tristate enum type
-     *
-     * This type defines a boolean which can be unset, i.e.
-     * this type has three states. The enum is ordered so
-     * that
-     *
-     * UNSET -> -1
-     * FALSE -> 0
-     * TRUE  -> 1
-     *
-     * And the integer values can be used directly when
-     * converting to string.
-     */
-    NETPLAN_TRISTATE_UNSET = -1, /* -1 */
-    NETPLAN_TRISTATE_FALSE,      /*  0 */
-    NETPLAN_TRISTATE_TRUE,       /*  1 */
-} NetplanTristate;
-
 typedef struct netplan_vxlan NetplanVxlan;
 
 /* Keep 'struct netplan_net_definition' in a separate header file, to allow for
@@ -414,4 +428,6 @@ struct netplan_net_definition {
 
     NetplanTristate bridge_hairpin;
     NetplanTristate bridge_learning;
+
+    NetplanRAOverrides ra_overrides;
 };
