@@ -71,7 +71,7 @@ is_hostname(const char *hostname)
 gboolean
 is_wireguard_key(const char* key)
 {
-    /* Check if this is (most likely) a 265bit, base64 encoded wireguard key */
+    /* Check if this is (most likely) a 256 bit, base64 encoded wireguard key */
     if (strlen(key) == 44 && key[43] == '=' && key[42] != '=') {
         static const gchar *pattern = "^(?:[A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{3}=)+$";
         return g_regex_match_simple(pattern, key, 0, G_REGEX_MATCH_NOTEMPTY);
@@ -337,7 +337,7 @@ validate_tunnel_backend_rules(const NetplanParser* npp, NetplanNetDefinition* nd
 gboolean
 validate_netdef_grammar(const NetplanParser* npp, NetplanNetDefinition* nd, GError** error)
 {
-    int missing_id_count = g_hash_table_size(npp->missing_id);
+    guint missing_id_count = g_hash_table_size(npp->missing_id);
     gboolean valid = FALSE;
     NetplanBackend backend = nd->backend;
 
